@@ -22,8 +22,8 @@
 #ifndef KDEVPLATFORM_BREAKPOINTDETAILS_H
 #define KDEVPLATFORM_BREAKPOINTDETAILS_H
 
-#include <QtGui/QWidget>
-#include "../debuggerexport.h"
+#include <QWidget>
+#include "debuggerexport.h"
 
 class QSpinBox;
 class QLabel;
@@ -35,9 +35,9 @@ class KDEVPLATFORMDEBUGGER_EXPORT BreakpointDetails : public QWidget
 {
     Q_OBJECT
 public:
-    BreakpointDetails(QWidget *parent);
+    explicit BreakpointDetails(QWidget *parent = nullptr);
 
-    void setItem(Breakpoint *b);
+    void setItem(Breakpoint *breakpoint);
 
 private Q_SLOTS:
     void showExplanation(const QString& link);
@@ -45,9 +45,9 @@ private Q_SLOTS:
     void setIgnoreHits(int ignoreHits);
 
 private:
-    QLabel* status_;
-    QLabel* hits_;
-    QSpinBox* ignore_;
+    QLabel* m_status;
+    QLabel* m_hits;
+    QSpinBox* m_ignore;
     Breakpoint* m_currentBreakpoint;
 };
 
